#!/bin/bash

SELFNAME="$0"
SELFDIR=$(dirname "$SELFNAME")
NEW_TIMESTAMP=
NODE_ID=$(cat /etc/hostname)

mosquitto_pub -q 2 -r -t /iq/bridge/migrate/status -m \
    "$(date) Готово к миграции"

# Ждем команды для миграции
mosquitto_sub -t /iq/bridge/migrate -R -C 5

# Запрвшиваем аргументы
mosquitto_pub -q 2 -r -t /iq/bridge/migrate/status -m \
    "$(date) Начинаем процесс обновления. Отправьте аргументы в топик /iq/{NODE_ID}/migrate/args"

# Ждем аргументы
ARGS=$(timeout 160 mosquitto_sub -t /iq/bridge/migrate/args -C 1 -R)
if [ -z "$ARGS" ]; then
    mosquitto_pub -q 2 -r -t /iq/bridge/migrate/status -m "$(date) Аргументы не были получены. Начните сначала."
    exit 1
fi

# Аргументы получены, продолжаем...
mosquitto_pub -q 2 -r -t /iq/bridge/migrate/status -m \
    "$(date) Аргументы получены, продолжаем"

# Делаем бекап текущего конфига mosquitto. Если не получается, выходим с ошибкой
cp /etc/mosquitto/mosquitto.conf /etc/mosquitto/mosquitto.conf.backup && cp /mnt/data/etc/mosquitto/conf.d/bridge.conf /mnt/data/etc/mosquitto/conf.d/bridge.conf.backup
BACKUP=$?

if [ $BACKUP -ne 0 ] ; then
    mosquitto_pub -q 2 -t /iq/bridge/migrate/status -m "$(date) Ошибка создания резервной копии старого конфига"
    exit 3
fi

# Выполняем скрипт обновления
/usr/bin/iqnergy/installer/configure_mosquitto.sh ${ARGS}
RET=$?
if [ $RET -ne 0 ] ; then
    mosquitto_pub -q 2 -t /iq/bridge/migrate/status -m "$(date) Ошибка выполнения скрипта обновления. $RET"
else
    systemctl restart mosquitto
    RET=$?
fi

# Если mosquitto перезапустился и конфиг обновился без ошибок, ждем пинг от сервера
if [ $RET -eq 0 ]; then
    sleep 10
    NEW_TIMESTAMP=$(timeout 60 mosquitto_sub -t /devices/lastseen/controls/server/on -R -C 2)
else
    mosquitto_pub -r -t /iq/bridge/migrate/status -m "$(date) Ошибка выполнения миграции. Код $INSTALLER_RET"
fi

# Если timestamp пустой, восстанавливаемся из бекапа
# Пустой timestamp будет в случае ошибки обновления или ошибки перезапуска mosquitto
if [ -z "$NEW_TIMESTAMP" ]; then
    cp /etc/mosquitto/mosquitto.conf.backup /etc/mosquitto/mosquitto.conf
    cp /mnt/data/etc/mosquitto/conf.d/bridge.conf.backup /mnt/data/etc/mosquitto/conf.d/bridge.conf
    systemctl restart mosquitto
    sleep 10
    mosquitto_pub -q 2 -r -t /iq/bridge/migrate/status -m "$(date) Timestamp не получен! Выполнен откат к старым настройкам."
    exit 4
fi

mosquitto_pub -q 2 -r -t /iq/bridge/migrate/status -m "$(date) Шаблон обновлен!"

# Отправляем ключ на новый сервер MQTT
PUBKEY=$(echo -e "Публичный ключ на $(date):\n$(cat /root/.ssh/id_rsa.pub)")
mosquitto_pub -t /iq/bridge/pubkey -r -m "$PUBKEY" -q 2

#######################################
# Конфигурирование lsyncd
echo -e "$(eval "echo -e \"`cat \"$SELFDIR/lsyncd/lsyncd.conf.lua.template\"`\"")" > "/etc/lsyncd/lsyncd.conf.lua"
rsync "$SELFDIR/lsyncd/lsyncd" "/etc/logrotate.d/"

systemctl stop lsyncd
systemctl start lsyncd
#######################################
#######################################


#######################################
# Обновляем информацию о версии шаблона mosquitto
mosquitto_pub -r -t /iq/bridge/upgrade/bridge_version -q 2 -m "$(head -n 2 /mnt/data/etc/mosquitto/conf.d/bridge.conf)"
mosquitto_pub -r -t /devices/system/controls/bridges -q 2 -m "$(grep -a address /mnt/data/etc/mosquitto/conf.d/bridge.conf)"
#######################################
#######################################
